==> client-sso-oidc-3.36.1.tgz: package/dist-es/endpoints.js <==
import { __assign, __awaiter, __generator } from "tslib";
import { getRegionInfo } from "@aws-sdk/config-resolver";
var regionHash = {
    "ap-northeast-1": {
        hostname: "oidc.ap-northeast-1.amazonaws.com",
        signingRegion: "ap-northeast-1",
    },
    "ap-northeast-2": {
        hostname: "oidc.ap-northeast-2.amazonaws.com",
        signingRegion: "ap-northeast-2",
    },
    "ap-south-1": {
        hostname: "oidc.ap-south-1.amazonaws.com",
        signingRegion: "ap-south-1",
    },
    "ap-southeast-1": {
        hostname: "oidc.ap-southeast-1.amazonaws.com",
        signingRegion: "ap-southeast-1",
    },
    "ap-southeast-2": {
        hostname: "oidc.ap-southeast-2.amazonaws.com",
        signingRegion: "ap-southeast-2",
    },
    "ca-central-1": {
        hostname: "oidc.ca-central-1.amazonaws.com",
        signingRegion: "ca-central-1",
    },
    "eu-central-1": {
        hostname: "oidc.eu-central-1.amazonaws.com",
        signingRegion: "eu-central-1",
    },
    "eu-north-1": {
        hostname: "oidc.eu-north-1.amazonaws.com",
        signingRegion: "eu-north-1",
    },
    "eu-west-1": {
        hostname: "oidc.eu-west-1.amazonaws.com",
        signingRegion: "eu-west-1",
    },
    "eu-west-2": {
        hostname: "oidc.eu-west-2.amazonaws.com",
        signingRegion: "eu-west-2",
    },
    "eu-west-3": {
        hostname: "oidc.eu-west-3.amazonaws.com",
        signingRegion: "eu-west-3",
    },
    "sa-east-1": {
        hostname: "oidc.sa-east-1.amazonaws.com",
        signingRegion: "sa-east-1",
    },
    "us-east-1": {
        hostname: "oidc.us-east-1.amazonaws.com",
        signingRegion: "us-east-1",
    },
    "us-east-2": {
        hostname: "oidc.us-east-2.amazonaws.com",
        signingRegion: "us-east-2",
    },
    "us-gov-west-1": {
        hostname: "oidc.us-gov-west-1.amazonaws.com",
        signingRegion: "us-gov-west-1",
    },
    "us-west-2": {
        hostname: "oidc.us-west-2.amazonaws.com",
        signingRegion: "us-west-2",
    },
};
var partitionHash = {
    aws: {
        regions: [
            "af-south-1",
            "ap-east-1",
            "ap-northeast-1",
            "ap-northeast-2",
            "ap-northeast-3",
            "ap-south-1",
            "ap-southeast-1",
            "ap-southeast-2",
            "ca-central-1",
            "eu-central-1",
            "eu-north-1",
            "eu-south-1",
            "eu-west-1",
            "eu-west-2",
            "eu-west-3",
            "me-south-1",
            "sa-east-1",
            "us-east-1",
            "us-east-2",
            "us-west-1",
            "us-west-2",
        ],
        hostname: "oidc.{region}.amazonaws.com",
    },
    "aws-cn": {
        regions: ["cn-north-1", "cn-northwest-1"],
        hostname: "oidc.{region}.amazonaws.com.cn",
    },
    "aws-iso": {
        regions: ["us-iso-east-1"],
        hostname: "oidc.{region}.c2s.ic.gov",
    },
    "aws-iso-b": {
        regions: ["us-isob-east-1"],
        hostname: "oidc.{region}.sc2s.sgov.gov",
    },
    "aws-us-gov": {
        regions: ["us-gov-east-1", "us-gov-west-1"],
        hostname: "oidc.{region}.amazonaws.com",
    },
};
export var defaultRegionInfoProvider = function (region, options) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        return [2, getRegionInfo(region, __assign(__assign({}, options), { signingService: "awsssooidc", regionHash: regionHash, partitionHash: partitionHash }))];
    });
}); };

==> client-sso-oidc-3.37.0.tgz: package/dist-es/endpoints.js <==
import { __assign, __awaiter, __generator } from "tslib";
import { getRegionInfo } from "@aws-sdk/config-resolver";
var regionHash = {
    "ap-northeast-1": {
        hostname: "oidc.ap-northeast-1.amazonaws.com",
        signingRegion: "ap-northeast-1",
    },
    "ap-northeast-2": {
        hostname: "oidc.ap-northeast-2.amazonaws.com",
        signingRegion: "ap-northeast-2",
    },
    "ap-south-1": {
        hostname: "oidc.ap-south-1.amazonaws.com",
        signingRegion: "ap-south-1",
    },
    "ap-southeast-1": {
        hostname: "oidc.ap-southeast-1.amazonaws.com",
        signingRegion: "ap-southeast-1",
    },
    "ap-southeast-2": {
        hostname: "oidc.ap-southeast-2.amazonaws.com",
        signingRegion: "ap-southeast-2",
    },
    "ca-central-1": {
        hostname: "oidc.ca-central-1.amazonaws.com",
        signingRegion: "ca-central-1",
    },
    "eu-central-1": {
        hostname: "oidc.eu-central-1.amazonaws.com",
        signingRegion: "eu-central-1",
    },
    "eu-north-1": {
        hostname: "oidc.eu-north-1.amazonaws.com",
        signingRegion: "eu-north-1",
    },
    "eu-west-1": {
        hostname: "oidc.eu-west-1.amazonaws.com",
        signingRegion: "eu-west-1",
    },
    "eu-west-2": {
        hostname: "oidc.eu-west-2.amazonaws.com",
        signingRegion: "eu-west-2",
    },
    "eu-west-3": {
        hostname: "oidc.eu-west-3.amazonaws.com",
        signingRegion: "eu-west-3",
    },
    "sa-east-1": {
        hostname: "oidc.sa-east-1.amazonaws.com",
        signingRegion: "sa-east-1",
    },
    "us-east-1": {
        hostname: "oidc.us-east-1.amazonaws.com",
        signingRegion: "us-east-1",
    },
    "us-east-2": {
        hostname: "oidc.us-east-2.amazonaws.com",
        signingRegion: "us-east-2",
    },
    "us-gov-west-1": {
        hostname: "oidc.us-gov-west-1.amazonaws.com",
        signingRegion: "us-gov-west-1",
    },
    "us-west-2": {
        hostname: "oidc.us-west-2.amazonaws.com",
        signingRegion: "us-west-2",
    },
};
var partitionHash = {
    aws: {
        regions: [
            "af-south-1",
            "ap-east-1",
            "ap-northeast-1",
            "ap-northeast-2",
            "ap-northeast-3",
            "ap-south-1",
            "ap-southeast-1",
            "ap-southeast-2",
            "ca-central-1",
            "eu-central-1",
            "eu-north-1",
            "eu-south-1",
            "eu-west-1",
            "eu-west-2",
            "eu-west-3",
            "me-south-1",
            "sa-east-1",
            "us-east-1",
            "us-east-2",
            "us-west-1",
            "us-west-2",
        ],
        hostname: "oidc.{region}.amazonaws.com",
    },
    "aws-cn": {
        regions: ["cn-north-1", "cn-northwest-1"],
        hostname: "oidc.{region}.amazonaws.com.cn",
    },
    "aws-iso": {
        regions: ["us-iso-east-1", "us-iso-west-1"],
        hostname: "oidc.{region}.c2s.ic.gov",
    },
    "aws-iso-b": {
        regions: ["us-isob-east-1"],
        hostname: "oidc.{region}.sc2s.sgov.gov",
    },
    "aws-us-gov": {
        regions: ["us-gov-east-1", "us-gov-west-1"],
        hostname: "oidc.{region}.amazonaws.com",
    },
};
export var defaultRegionInfoProvider = function (region, options) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        return [2, getRegionInfo(region, __assign(__assign({}, options), { signingService: "awsssooidc", regionHash: regionHash, partitionHash: partitionHash }))];
    });
}); };
